@@ -16,8 +16,8 @@ no warnings "experimental::lexical_subs";
 
 package  Data::Dumper::Interp;
 { no strict 'refs'; ${__PACKAGE__."::VER"."SION"} = 997.999; }
-our $VERSION = '5.029'; # VERSION from Dist::Zilla::Plugin::OurPkgVersion
-our $DATE = '2023-07-09'; # DATE from Dist::Zilla::Plugin::OurDate
+our $VERSION = '5.030'; # VERSION from Dist::Zilla::Plugin::OurPkgVersion
+our $DATE = '2023-07-10'; # DATE from Dist::Zilla::Plugin::OurDate
 
 package
   # newline so Dist::Zilla::Plugin::PkgVersion won't add $VERSION
@@ -422,14 +422,14 @@ sub _get_terminal_width() {  # returns undef if unknowable
       local $SIG{'__WARN__'} = sub { $wmsg .= $_[0] };
       $fh ? Term::ReadKey::GetTerminalSize($fh) : ()
     };
-    return $width; # possibly undef
+    return $width; # possibly undef (sometimes seems to be zero ?!?)
   }
 }
 
 sub _set_default_Foldwidth() {
   my $self = shift;
   _SaveAndResetPunct();
-  $Foldwidth = _get_terminal_width // 80;
+  $Foldwidth = _get_terminal_width || 80;
   _RestorePunct();
   undef $Foldwidth1;
 }
