@@ -20,8 +20,8 @@ use strict; use warnings  FATAL => 'all'; use feature qw/say state/;
 
 require Exporter;
 use parent 'Exporter';
-our @EXPORT = qw/oops mytempfile mytempdir/;
-our @EXPORT_OK = ();
+our @EXPORT = qw/mytempfile mytempdir/;
+our @EXPORT_OK = qw/oops/;
 
 use Import::Into;
 use Carp;
@@ -38,15 +38,15 @@ sub import {
     # some non-default pragma is in effect.  I can't figure any other
     # reason why we would be imported twice, with non-default settings
     # the 2nd time.
-    
+
     # Check that the user did not already say "no warnings ..." or somesuch
-    # I was confused about how to this before, 
+    # I was previously confused about how to do this,
     # see https://rt.cpan.org/Ticket/Display.html?id=147618
     my $users_warnbits = ${^WARNING_BITS}//"u";
     my $users_pragmas = ($^H//"u").":".hash2str(\%^H);
     carp "Detected 'use/no warnings/strict' done before importing ",
           __PACKAGE__, "\n(they might be un-done)\n"
-      if ($users_pragmas ne $default_pragmas 
+      if ($users_pragmas ne $default_pragmas
             || $users_warnbits ne $default_warnbits);
   }
   strict->import::into($target);
@@ -57,8 +57,9 @@ sub import {
   use 5.011;  # cpantester gets warning that 5.11 is the minimum acceptable
   use 5.018;  # lexical_subs
   require feature;
-  feature->import::into($target, qw/state say current_sub lexical_subs/);
+  # Perl 5.18.0 seems to require the "no experimental..." before the "use feature"
   warnings->unimport::out_of($target, "experimental::lexical_subs");
+  feature->import::into($target, qw/state say current_sub lexical_subs fc/);
 
   # die if obsolete or dangerous syntax is used
   require indirect;
@@ -68,8 +69,13 @@ sub import {
   multidimensional->unimport::out_of($target);
 
   require autovivification;
-  autovivification->unimport::out_of($target,
-                warn => qw/fetch store exists delete/);
+  # A bug makes
+  #   "no autovivification warn anything..." wrongly flag
+  #   "my %hash; delete $hash{nonexistentkey}"
+  # This happens with Perl 5.24.0 and autovivification v0.18
+  # but not with Perl5.34.0 and same autovivification.
+  # So just disable autoviv but don't enable warnings...
+  autovivification->unimport::out_of($target, qw/fetch store exists delete/);
 
   # Avoid regex performance penalty in Perl <= 5.18 if
   # $PREMATCH $MATCH or $POSTMATCH are imported (fixed in perl 5.20).
@@ -87,36 +93,37 @@ sub import {
   require File::Basename;
   File::Basename->import::into($target, qw/basename dirname/);
 
-  # NO. use mytempfile or mytempdir
-  #require File::Temp;
-  #File::Temp->import::into($target, qw/tempfile tempdir/);
-
   require File::Path;
   File::Path->import::into($target, qw/make_path rmtree/);
 
   require File::Spec;
   require File::Spec::Functions;
+  # Do *not* import 'devnull' as it doesn't really work on Windows,
+  # at least not as the input to File::Copy::copy (fails with "No such file")
   File::Spec::Functions->import::into($target, qw/
     canonpath catdir catfile curdir rootdir updir
-    no_upwards file_name_is_absolute devnull tmpdir splitpath splitdir 
+    no_upwards file_name_is_absolute tmpdir splitpath splitdir
     abs2rel rel2abs case_tolerant/);
 
+  require Path::Tiny;
+  Path::Tiny->import::into($target, qw/path/);
+
   require List::Util;
   List::Util->import::into($target, qw/reduce min max first any all none sum0/);
 
 
 
   require Scalar::Util;
-  Scalar::Util->import::into($target, qw/blessed reftype looks_like_number 
+  Scalar::Util->import::into($target, qw/blessed reftype looks_like_number
                                          weaken isweak refaddr/);
 
   require Cwd;
-  Cwd->import::into($target, qw/getcwd abs_path/);
+  Cwd->import::into($target, qw/getcwd abs_path fastgetcwd fast_abs_path/);
 
   require Guard;
   Guard->import::into($target, qw(scope_guard guard));
 
-  unless (Cwd::abs_path(__FILE__) =~ /Data-Dumper-Interp/) { 
+  unless (Cwd::abs_path(__FILE__) =~ /Data-Dumper-Interp/) {
     # unless we are testing this
     require Data::Dumper::Interp;
     Data::Dumper::Interp->import::into($target);
@@ -129,36 +136,16 @@ sub import {
 
 use File::Temp 0.23 ();
 
-# These wrappers provide sane defaults:
-#   TMPDIR set and the appropriate clean-up option enabled.
-# In addition, if a single "template" argument is a full filename including
-# suffix (i.e. does not end in ...XXX), then it is split into separate
-# TEMPLATE and SUFFIX arguments for File::Temp
-sub _process_tfargs(@) {
-  return @_ if (scalar(@_) % 2 == 0); # already key => value, ....
-  (local $_, my @rest) = @_;
-  if (s/X([^X]+)$/X/) { unshift @rest, SUFFIX => $1; }
-  (TEMPLATE => $_, @rest)
+sub mytempfile { ##DEPRECATED
+  Path::Tiny->tempfile(@_); # does everything we used to do
 }
-sub mytempfile {
-  my @tfargs = _process_tfargs(@_);
-  File::Temp::tempfile(
-    TMPDIR => File::Spec->tmpdir(),
-    UNLINK  =>  1,
-    @tfargs
-  )
+sub mytempdir {  ##DEPRECATED
+  Path::Tiny->tempdir(@_); # does everything we used to do
 }
-sub mytempdir {
-  my @tfargs = _process_tfargs(@_);
-  File::Temp::tempdir(
-    TMPDIR => File::Spec->tmpdir(),
-    CLEANUP =>  1,
-    @tfargs
-  )
-}
-# prevent direct use of File::Temp by exporting these conflicting stubs
-# ?? Maybe just name our wrappers without the "my" and let them be imported explicitly?
-sub tempfile { confess "call mytempfile instead" }
-sub tempdir  { confess "call mytempdir instead" }
+
+# prevent direct use of File::Temp with it's confusing arguments
+# by exporting these conflicting stubs
+sub tempfile { confess "use Path::Tiny->tempfile(...) instead" }
+sub tempdir  { confess "use Path::Tiny->tempdir(...) instead" }
 
 1;
